import axios from '@utils/ajax'
import {
  initItems,
  delItems,
  batchDelItems,
  changeTitle,
  keepPushData,
  changeVisible,
  getDptLis,
  initAdminItems,
  delItemsAdmin,
  batchDelItemsAdmin,
  changeTitleAdmin,
} from '@store/actions/tabTemplate';
import {DIAG_SHOW} from "@store/types/print";
import Notify from '@commonComp/Notify';
import store from '@store';
import {
  getAllDataList,
  getAllDataStringList,
  pushAllDataList,
  getUrlArgObject,
  didPushParamChange
} from '@utils/tools';
import { billing } from '@store/async-actions/pushMessage';

export const initItemList = (current,name) => {
  let admin = store.getState().homePage.admin;
  if(admin){
    return initAdminItemList(current,name)
  }else{
    return initCommonItemList(current,name)
  }
}

export const initCommonItemList = (current,name) => { //初始化数据
  let baseList = store.getState();
  let state = baseList.patInfo.message;
  // let searchVal = document.getElementById("searchTmp").value
  return (dispatch) => {
    axios.json('/templateInfo/getTemplatePageAlls', {
      "doctorId": state.doctorId,
      "hospitalDeptId": (name == '')?state.hospitalDeptId:null,
      "hospitalId": state.hospitalId,
      "hospitalCode": state.hospitalCode,
      "current": current,
      "sex":[1,2,3],
      "size": 9999,
      "name":name||''
    }).then((res) => {
      const data = res.data;
      if (data.code == 0) {
        // data.data.flg = flg||false  //获取下一页，暂时不用
        dispatch(initItems(data.data));
      } else {
        Notify.error(data.msg)
      }
    })
  }
};
export const initAdminItemList = (current,name) => { //初始化数据
  let baseList = store.getState();
  // let searchVal = document.getElementById("searchTmp").value
  let state = baseList.patInfo.message;
  return (dispatch) => {
    axios.json('/templateAdmin/getTemplatePageAlls', {
      "doctorId": state.doctorId,
      "hospitalDeptId": '',
      "hospitalId": state.hospitalId,
      "hospitalCode": state.hospitalCode,
      "current": current,
      "sex":[1,2,3],
      "size": 9999,
      "name":name||''
    }).then((res) => {
      const data = res.data;
      if (data.code == 0) {
        // data.data.flg = flg||false  //获取下一页，暂时不用
        dispatch(initAdminItems(data.data));
      } else {
        Notify.error(data.msg)
      }
    })
  }
};

export const saveTemplateDetail = (val,sex) => { //保存为模板
  let baseList = store.getState();
  let jsonData = getAllDataList(baseList);
  let jsonStr = getAllDataStringList(baseList);
  const dConfig = baseList.typeConfig;
  const readMode = dConfig.readMode;          //回读模式
  let whichSign = readMode===-1||readMode===null?dConfig.mode:readMode;
  const docConfigs = dConfig.readConfig===-1||!dConfig.readConfig?dConfig.typeConfig:dConfig.readConfig;
  jsonData.docConfigs=docConfigs;     //保存当时的设置引用
  let state = baseList.patInfo.message;
  let preview = {
    "chief": jsonStr.chief,
    "present": jsonStr.present,
    "other": jsonStr.other,
    "vital": jsonStr.vital,
    "lis": jsonStr.lis,
    "pacs": jsonStr.pacs,
    "diag": jsonStr.diag,
    "advice": jsonStr.advice,
  }
  function getdata(idx){
    let tmpObj = {
      "doctorId": state.doctorId,
      "hospitalDeptId": state.hospitalDeptId,
      "hospitalId": state.hospitalId,
      "dataJson": JSON.stringify(jsonData),
      "modeName": val,
      "modeType": whichSign,
      "preview": idx ? JSON.stringify(preview):preview,
      "sex":sex
    }
    return tmpObj;
  }
  return (dispatch) => {
    axios.json('/templateInfo/saveTemplateInfo', getdata()).then((res) => {
      const data = res.data;
      if (data.code == 0) {
        Notify.success('模板保存成功');
        dispatch(initItemList(1,""));
        dispatch(keepPushData(getdata(1),'part'));
        dispatch({
          type: DIAG_SHOW,
          data:false
        });
      } else {
        if(data.msg == '该模板名存在'){         //存在不关闭弹窗
          dispatch({
            type: DIAG_SHOW,
            data:true
          });
        }else{
          dispatch({
            type: DIAG_SHOW,
            data:false
          });
        }
        Notify.error(data.msg);
      }
    })
  }
};
export const saveAdminTemplateDetail = (val,sex,id) => { //保存为模板
  let baseList = store.getState();
  let jsonData = getAllDataList(baseList);
  let jsonStr = getAllDataStringList(baseList);
  const dConfig = baseList.typeConfig;
  const readMode = dConfig.readMode;          //回读模式
  let whichSign = readMode===-1||readMode===null?dConfig.mode:readMode;
  const docConfigs = dConfig.readConfig===-1||!dConfig.readConfig?dConfig.typeConfig:dConfig.readConfig;
  jsonData.docConfigs=docConfigs;     //保存当时的设置引用
  let state = baseList.patInfo.message;
  let preview = {
    "chief": jsonStr.chief,
    "present": jsonStr.present,
    "other": jsonStr.other,
    "vital": jsonStr.vital,
    "lis": jsonStr.lis,
    "pacs": jsonStr.pacs,
    "diag": jsonStr.diag,
    "advice": jsonStr.advice,
  }
  function getdata(idx){
    let tmpObj = {
      "doctorId": state.doctorId,
      "hospitalDeptId": id,
      "hospitalId": state.hospitalId,
      "dataJson": JSON.stringify(jsonData),
      "modeName": val,
      "modeType": whichSign,
      "preview": idx ? JSON.stringify(preview):preview,
      "sex":sex
    }
    return tmpObj;
  }
  return (dispatch) => {
    axios.json('/templateAdmin/saveTemplateAdmin', getdata()).then((res) => {
      const data = res.data;
      if (data.code == 0) {
        Notify.success('模板保存成功');
        dispatch(initItemList(1,""));
        dispatch(keepPushData(getdata(1),'part'));
        dispatch({
          type: DIAG_SHOW,
          data:false
        });
      } else {
        if(data.msg == '该模板名存在'){         //存在不关闭弹窗
          dispatch({
            type: DIAG_SHOW,
            data:true
          });
        }else{
          dispatch({
            type: DIAG_SHOW,
            data:false
          });
        }
        Notify.error(data.msg);
      }
    })
  }
};

export const delItem = (id) => { //删除
  return (dispatch) => {
    axios.json('/templateInfo/cancelTemplateInfos', {
      ids: id
    }).then((res) => {
      let data = res.data;
      if (data.code == 0) {
        dispatch(delItems(id));
        Notify.success('模板删除成功');
      } else {
        Notify.error(data.msg);
      }
    })
  }
};
export const delItemAdmin = (id) => { //删除
  let baseList = store.getState().patInfo.message;
  return (dispatch) => {
    axios.json('/templateAdmin/cancelTemplateAdminb', {
      "ids": id, 
      "doctorId": baseList.doctorId,
      "hospitalId": baseList.hospitalId,
    }).then((res) => {
      let data = res.data;
      if (data.code == 0) {
        dispatch(delItemsAdmin(id));
        Notify.success('模板删除成功');
      } else {
        Notify.error(data.msg);
      }
    })
  }
};
export const delBatchItem = (ids) => { //批量删除
  return (dispatch) => {
    axios.json('/templateInfo/cancelTemplateInfos', {
      ids: ids.join(",")
    }).then((res) => {
      let data = res.data;
      if (data.code == 0) {
        dispatch(batchDelItems(ids));
      } else {
        Notify.error(data.msg);
      }
    })
  }
};
export const delBatchItemAdmin = (ids) => { //批量删除
  let baseList = store.getState().patInfo.message;
  return (dispatch) => {
    axios.json('/templateAdmin/cancelTemplateAdminb', {
      "ids": ids.join(","), 
      "doctorId": baseList.doctorId,
      "hospitalId": baseList.hospitalId,
    }).then((res) => {
      let data = res.data;
      if (data.code == 0) {
        dispatch(batchDelItemsAdmin(ids));
      } else {
        Notify.error(data.msg);
      }
    })
  }
};

export const changeTitleAsyncAdmin = (obj) => { //改标题
  let baseList = store.getState();
  let whichSign = baseList.typeConfig.mode;
  let state = baseList.patInfo.message;
  return (dispatch) => {
    axios.json('/templateAdmin/updateByAdminNames', {
      "doctorId": state.doctorId,
      "hospitalDeptId": obj.deptId,
      "hospitalId": state.hospitalId,
      "id": obj.id,
      "modeName": obj.title,
      "type": whichSign
    }).then((res) => {
      let data = res.data;
      if (data.code == 0) {
        dispatch(changeTitleAdmin(obj));
        Notify.success('标题修改成功');
        store.dispatch(changeVisible(false))
      } else {
        // console.log(data)
        Notify.error(data.msg)
      }
    })
  }
};
export const changeTitleAsync = (obj) => { //改标题
  let baseList = store.getState();
  let whichSign = baseList.typeConfig.mode;
  let state = baseList.patInfo.message;
  return (dispatch) => {
    axios.json('/templateInfo/updateByIdUsNames', {
      "doctorId": state.doctorId,
      "hospitalDeptId": obj.deptId,
      "hospitalId": state.hospitalId,
      "id": obj.id,
      "modeName": obj.title,
      "type": whichSign
    }).then((res) => {
      let data = res.data;
      if (data.code == 0) {
        dispatch(changeTitle(obj));
        Notify.success('标题修改成功');
        store.dispatch(changeVisible(false))
      } else {
        // console.log(data)
        Notify.error(data.msg)
      }
    })
  }
};

export const setPageView = (id) => { //获取模板结构化数据
  return (dispatch) => {
    axios.json('/templateInfo/getTemplateIdAlls', {
      id: id
    }).then((res) => {
      let data = res.data;
      if (data.code == 0) {
        //模板列表不筛选模式后，单个模式引用时看本身的模式
        pushAllDataList(data.data.type, 'push', data.data, 'template')//引用
        if(didPushParamChange()){     //诊断变化时会调推送，避免重复调
          dispatch(billing())
        }
      } else {
        Notify.error(data.msg);
      }
    })
  }
};
export const setPageViewAdmin = (id) => { //获取模板结构化数据
  return (dispatch) => {
    axios.json('/templateAdmin/getTemplateIdAlls', {
      id: id
    }).then((res) => {
      let data = res.data;
      if (data.code == 0) {
        //模板列表不筛选模式后，单个模式引用时看本身的模式
        pushAllDataList(data.data.type, 'push', data.data, 'template')//引用
        if(didPushParamChange()){     //诊断变化时会调推送，避免重复调
          dispatch(billing())
        }
      } else {
        Notify.error(data.msg);
      }
    })
  }
};

export const getDepartments = (value) => { //获取模板结构化数据
  return (dispatch) => {
    axios.json('/doctorInfo/getHospitalDeptInfoAll', {
      "deptInfoName": value,
      "hospitalCode": getUrlArgObject('hospitalId'),
      "thirdpartyName": ""
    }).then((res) => {
      let data = res.data;
      if (data.code == 0) {
        dispatch(getDptLis(data.data))
      } else {
        Notify.error(data.msg);
      }
    })
  }
};